# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class AddNode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_id': 'int'
    }

    attribute_map = {
        'node_id': 'node_id'
    }

    def __init__(self, node_id=None, _configuration=None):  # noqa: E501
        """AddNode - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._node_id = None
        self.discriminator = None

        self.node_id = node_id

    @property
    def node_id(self):
        """Gets the node_id of this AddNode.  # noqa: E501


        :return: The node_id of this AddNode.  # noqa: E501
        :rtype: int
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this AddNode.


        :param node_id: The node_id of this AddNode.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and node_id is None:
            raise ValueError("Invalid value for `node_id`, must not be `None`")  # noqa: E501

        self._node_id = node_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddNode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddNode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.fault_domains_api import FaultDomainsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestFaultDomainsApi(unittest.TestCase):
    """FaultDomainsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.fault_domains_api.FaultDomainsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_node(self):
        """Test case for add_node

        """
        pass

    def test_get_fault_domain_details(self):
        """Test case for get_fault_domain_details

        """
        pass

    def test_get_fault_domains(self):
        """Test case for get_fault_domains

        """
        pass

    def test_get_inventory(self):
        """Test case for get_inventory

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.cloud_users_api import CloudUsersApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCloudUsersApi(unittest.TestCase):
    """CloudUsersApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.cloud_users_api.CloudUsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_allocate_vlan(self):
        """Test case for allocate_vlan

        """
        pass

    def test_delete_tenant(self):
        """Test case for delete_tenant

        """
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        """
        pass

    def test_get_tenants(self):
        """Test case for get_tenants

        """
        pass

    def test_list_cloud_user_comments(self):
        """Test case for list_cloud_user_comments

        """
        pass

    def test_list_cloud_vlans(self):
        """Test case for list_cloud_vlans

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200102VirtualNetworkInterfaces(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'custom_network_id': 'int',
        'vpsa_id': 'int',
        'id': 'int',
        'vni_id': 'int',
        'ip': 'str',
        'domain_rec_name': 'str',
        'fixed_address_0': 'str',
        'fixed_address_1': 'str',
        'cidr': 'str',
        'name': 'str',
        'vlan_id': 'int'
    }

    attribute_map = {
        'custom_network_id': 'custom_network_id',
        'vpsa_id': 'vpsa_id',
        'id': 'id',
        'vni_id': 'vni_id',
        'ip': 'ip',
        'domain_rec_name': 'domain_rec_name',
        'fixed_address_0': 'fixed_address_0',
        'fixed_address_1': 'fixed_address_1',
        'cidr': 'cidr',
        'name': 'name',
        'vlan_id': 'vlan_id'
    }

    def __init__(self, custom_network_id=None, vpsa_id=None, id=None, vni_id=None, ip=None, domain_rec_name=None, fixed_address_0=None, fixed_address_1=None, cidr=None, name=None, vlan_id=None, _configuration=None):  # noqa: E501
        """InlineResponse200102VirtualNetworkInterfaces - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._custom_network_id = None
        self._vpsa_id = None
        self._id = None
        self._vni_id = None
        self._ip = None
        self._domain_rec_name = None
        self._fixed_address_0 = None
        self._fixed_address_1 = None
        self._cidr = None
        self._name = None
        self._vlan_id = None
        self.discriminator = None

        if custom_network_id is not None:
            self.custom_network_id = custom_network_id
        if vpsa_id is not None:
            self.vpsa_id = vpsa_id
        if id is not None:
            self.id = id
        if vni_id is not None:
            self.vni_id = vni_id
        if ip is not None:
            self.ip = ip
        if domain_rec_name is not None:
            self.domain_rec_name = domain_rec_name
        if fixed_address_0 is not None:
            self.fixed_address_0 = fixed_address_0
        if fixed_address_1 is not None:
            self.fixed_address_1 = fixed_address_1
        if cidr is not None:
            self.cidr = cidr
        if name is not None:
            self.name = name
        if vlan_id is not None:
            self.vlan_id = vlan_id

    @property
    def custom_network_id(self):
        """Gets the custom_network_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The custom_network_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: int
        """
        return self._custom_network_id

    @custom_network_id.setter
    def custom_network_id(self, custom_network_id):
        """Sets the custom_network_id of this InlineResponse200102VirtualNetworkInterfaces.


        :param custom_network_id: The custom_network_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: int
        """

        self._custom_network_id = custom_network_id

    @property
    def vpsa_id(self):
        """Gets the vpsa_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The vpsa_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_id

    @vpsa_id.setter
    def vpsa_id(self, vpsa_id):
        """Sets the vpsa_id of this InlineResponse200102VirtualNetworkInterfaces.


        :param vpsa_id: The vpsa_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: int
        """

        self._vpsa_id = vpsa_id

    @property
    def id(self):
        """Gets the id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse200102VirtualNetworkInterfaces.


        :param id: The id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def vni_id(self):
        """Gets the vni_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The vni_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: int
        """
        return self._vni_id

    @vni_id.setter
    def vni_id(self, vni_id):
        """Sets the vni_id of this InlineResponse200102VirtualNetworkInterfaces.


        :param vni_id: The vni_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: int
        """

        self._vni_id = vni_id

    @property
    def ip(self):
        """Gets the ip of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The ip of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this InlineResponse200102VirtualNetworkInterfaces.


        :param ip: The ip of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def domain_rec_name(self):
        """Gets the domain_rec_name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The domain_rec_name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._domain_rec_name

    @domain_rec_name.setter
    def domain_rec_name(self, domain_rec_name):
        """Sets the domain_rec_name of this InlineResponse200102VirtualNetworkInterfaces.


        :param domain_rec_name: The domain_rec_name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._domain_rec_name = domain_rec_name

    @property
    def fixed_address_0(self):
        """Gets the fixed_address_0 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The fixed_address_0 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._fixed_address_0

    @fixed_address_0.setter
    def fixed_address_0(self, fixed_address_0):
        """Sets the fixed_address_0 of this InlineResponse200102VirtualNetworkInterfaces.


        :param fixed_address_0: The fixed_address_0 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._fixed_address_0 = fixed_address_0

    @property
    def fixed_address_1(self):
        """Gets the fixed_address_1 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The fixed_address_1 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._fixed_address_1

    @fixed_address_1.setter
    def fixed_address_1(self, fixed_address_1):
        """Sets the fixed_address_1 of this InlineResponse200102VirtualNetworkInterfaces.


        :param fixed_address_1: The fixed_address_1 of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._fixed_address_1 = fixed_address_1

    @property
    def cidr(self):
        """Gets the cidr of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The cidr of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this InlineResponse200102VirtualNetworkInterfaces.


        :param cidr: The cidr of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def name(self):
        """Gets the name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200102VirtualNetworkInterfaces.


        :param name: The name of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501


        :return: The vlan_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse200102VirtualNetworkInterfaces.


        :param vlan_id: The vlan_id of this InlineResponse200102VirtualNetworkInterfaces.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200102VirtualNetworkInterfaces, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200102VirtualNetworkInterfaces):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200102VirtualNetworkInterfaces):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CloudAppEngines(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default': 'str',
        'memory_mb': 'str',
        'name': 'str',
        'price': 'str',
        'specs': 'str',
        'vcpus': 'str'
    }

    attribute_map = {
        'default': 'default',
        'memory_mb': 'memory_mb',
        'name': 'name',
        'price': 'price',
        'specs': 'specs',
        'vcpus': 'vcpus'
    }

    def __init__(self, default=None, memory_mb=None, name=None, price=None, specs=None, vcpus=None, _configuration=None):  # noqa: E501
        """CloudAppEngines - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._default = None
        self._memory_mb = None
        self._name = None
        self._price = None
        self._specs = None
        self._vcpus = None
        self.discriminator = None

        if default is not None:
            self.default = default
        if memory_mb is not None:
            self.memory_mb = memory_mb
        if name is not None:
            self.name = name
        if price is not None:
            self.price = price
        if specs is not None:
            self.specs = specs
        if vcpus is not None:
            self.vcpus = vcpus

    @property
    def default(self):
        """Gets the default of this CloudAppEngines.  # noqa: E501


        :return: The default of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this CloudAppEngines.


        :param default: The default of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._default = default

    @property
    def memory_mb(self):
        """Gets the memory_mb of this CloudAppEngines.  # noqa: E501


        :return: The memory_mb of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._memory_mb

    @memory_mb.setter
    def memory_mb(self, memory_mb):
        """Sets the memory_mb of this CloudAppEngines.


        :param memory_mb: The memory_mb of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._memory_mb = memory_mb

    @property
    def name(self):
        """Gets the name of this CloudAppEngines.  # noqa: E501


        :return: The name of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CloudAppEngines.


        :param name: The name of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def price(self):
        """Gets the price of this CloudAppEngines.  # noqa: E501


        :return: The price of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this CloudAppEngines.


        :param price: The price of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._price = price

    @property
    def specs(self):
        """Gets the specs of this CloudAppEngines.  # noqa: E501


        :return: The specs of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._specs

    @specs.setter
    def specs(self, specs):
        """Sets the specs of this CloudAppEngines.


        :param specs: The specs of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._specs = specs

    @property
    def vcpus(self):
        """Gets the vcpus of this CloudAppEngines.  # noqa: E501


        :return: The vcpus of this CloudAppEngines.  # noqa: E501
        :rtype: str
        """
        return self._vcpus

    @vcpus.setter
    def vcpus(self, vcpus):
        """Sets the vcpus of this CloudAppEngines.


        :param vcpus: The vcpus of this CloudAppEngines.  # noqa: E501
        :type: str
        """

        self._vcpus = vcpus

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudAppEngines, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudAppEngines):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudAppEngines):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class RolesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_role(self, create_role, **kwargs):  # noqa: E501
        """create_role  # noqa: E501

        Create role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_role(create_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRole create_role: (required)
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_role_with_http_info(create_role, **kwargs)  # noqa: E501
        else:
            (data) = self.create_role_with_http_info(create_role, **kwargs)  # noqa: E501
            return data

    def create_role_with_http_info(self, create_role, **kwargs):  # noqa: E501
        """create_role  # noqa: E501

        Create role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_role_with_http_info(create_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRole create_role: (required)
        :return: InlineResponse20052
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_role']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_role' is set
        if self.api_client.client_side_validation and ('create_role' not in params or
                                                       params['create_role'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_role` when calling `create_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_role' in params:
            body_params = params['create_role']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/roles.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20052',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_role(self, id, **kwargs):  # noqa: E501
        """delete_role  # noqa: E501

        Delete role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_role_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_role_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_role  # noqa: E501

        Delete role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/roles/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_role(self, id, edit_role, **kwargs):  # noqa: E501
        """edit_role  # noqa: E501

        Edit role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_role(id, edit_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param EditRole edit_role: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_role_with_http_info(id, edit_role, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_role_with_http_info(id, edit_role, **kwargs)  # noqa: E501
            return data

    def edit_role_with_http_info(self, id, edit_role, **kwargs):  # noqa: E501
        """edit_role  # noqa: E501

        Edit role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_role_with_http_info(id, edit_role, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param EditRole edit_role: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'edit_role']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `edit_role`")  # noqa: E501
        # verify the required parameter 'edit_role' is set
        if self.api_client.client_side_validation and ('edit_role' not in params or
                                                       params['edit_role'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `edit_role` when calling `edit_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'edit_role' in params:
            body_params = params['edit_role']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/roles/{id}.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_role(self, id, **kwargs):  # noqa: E501
        """get_role  # noqa: E501

        Return role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_role_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_role_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_role_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_role  # noqa: E501

        Return role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_role_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20053
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/roles/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20053',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_all_permissions(self, **kwargs):  # noqa: E501
        """list_all_permissions  # noqa: E501

        Return permissions list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_all_permissions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_all_permissions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_all_permissions_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_all_permissions_with_http_info(self, **kwargs):  # noqa: E501
        """list_all_permissions  # noqa: E501

        Return permissions list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_all_permissions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20054
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_all_permissions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/permissions.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20054',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_roles(self, **kwargs):  # noqa: E501
        """list_roles  # noqa: E501

        Return roles list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_roles_with_http_info(self, **kwargs):  # noqa: E501
        """list_roles  # noqa: E501

        Return roles list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/roles.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20051',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20055PasswordStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'password_experation_limit': 'bool',
        'password_history': 'int'
    }

    attribute_map = {
        'password_experation_limit': 'password_experation_limit',
        'password_history': 'password_history'
    }

    def __init__(self, password_experation_limit=None, password_history=None, _configuration=None):  # noqa: E501
        """InlineResponse20055PasswordStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._password_experation_limit = None
        self._password_history = None
        self.discriminator = None

        if password_experation_limit is not None:
            self.password_experation_limit = password_experation_limit
        if password_history is not None:
            self.password_history = password_history

    @property
    def password_experation_limit(self):
        """Gets the password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501


        :return: The password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501
        :rtype: bool
        """
        return self._password_experation_limit

    @password_experation_limit.setter
    def password_experation_limit(self, password_experation_limit):
        """Sets the password_experation_limit of this InlineResponse20055PasswordStatus.


        :param password_experation_limit: The password_experation_limit of this InlineResponse20055PasswordStatus.  # noqa: E501
        :type: bool
        """

        self._password_experation_limit = password_experation_limit

    @property
    def password_history(self):
        """Gets the password_history of this InlineResponse20055PasswordStatus.  # noqa: E501


        :return: The password_history of this InlineResponse20055PasswordStatus.  # noqa: E501
        :rtype: int
        """
        return self._password_history

    @password_history.setter
    def password_history(self, password_history):
        """Sets the password_history of this InlineResponse20055PasswordStatus.


        :param password_history: The password_history of this InlineResponse20055PasswordStatus.  # noqa: E501
        :type: int
        """

        self._password_history = password_history

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20055PasswordStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20055PasswordStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20055PasswordStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class Cloud(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'uuid': 'str',
        'enabled': 'str',
        'app_engines': 'list[CloudAppEngines]',
        'nova_url': 'str',
        'auth_url': 'str',
        'keystone_url': 'str',
        'glance_url': 'str',
        'drive_types': 'list[CloudDriveTypes]',
        'engine_types': 'list[CloudEngineTypes]',
        'fibre_channel': 'CloudFibreChannel',
        'flash_cache': 'CloudFlashCache',
        'minimum_drives': 'int',
        'supports_app_engines': 'bool',
        'zios': 'CloudFibreChannel',
        'zones': 'list[CloudZones]',
        'vpsa_zone_group_storage_policy_types': 'CloudVpsazoneGroupStoragePolicyTypes',
        'recommended_storage_array_image_id': 'int',
        'last_synced': 'str',
        'sync_status': 'CloudSyncStatus'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'uuid': 'uuid',
        'enabled': 'enabled',
        'app_engines': 'app_engines',
        'nova_url': 'nova_url',
        'auth_url': 'auth_url',
        'keystone_url': 'keystone_url',
        'glance_url': 'glance_url',
        'drive_types': 'drive_types',
        'engine_types': 'engine_types',
        'fibre_channel': 'fibre_channel',
        'flash_cache': 'flash_cache',
        'minimum_drives': 'minimum_drives',
        'supports_app_engines': 'supports_app_engines',
        'zios': 'zios',
        'zones': 'zones',
        'vpsa_zone_group_storage_policy_types': 'vpsa-zone_group_storage_policy_types',
        'recommended_storage_array_image_id': 'recommended_storage_array_image_id',
        'last_synced': 'last_synced',
        'sync_status': 'sync_status'
    }

    def __init__(self, id=None, name=None, uuid=None, enabled=None, app_engines=None, nova_url=None, auth_url=None, keystone_url=None, glance_url=None, drive_types=None, engine_types=None, fibre_channel=None, flash_cache=None, minimum_drives=None, supports_app_engines=None, zios=None, zones=None, vpsa_zone_group_storage_policy_types=None, recommended_storage_array_image_id=None, last_synced=None, sync_status=None, _configuration=None):  # noqa: E501
        """Cloud - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._uuid = None
        self._enabled = None
        self._app_engines = None
        self._nova_url = None
        self._auth_url = None
        self._keystone_url = None
        self._glance_url = None
        self._drive_types = None
        self._engine_types = None
        self._fibre_channel = None
        self._flash_cache = None
        self._minimum_drives = None
        self._supports_app_engines = None
        self._zios = None
        self._zones = None
        self._vpsa_zone_group_storage_policy_types = None
        self._recommended_storage_array_image_id = None
        self._last_synced = None
        self._sync_status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if uuid is not None:
            self.uuid = uuid
        if enabled is not None:
            self.enabled = enabled
        if app_engines is not None:
            self.app_engines = app_engines
        if nova_url is not None:
            self.nova_url = nova_url
        if auth_url is not None:
            self.auth_url = auth_url
        if keystone_url is not None:
            self.keystone_url = keystone_url
        if glance_url is not None:
            self.glance_url = glance_url
        if drive_types is not None:
            self.drive_types = drive_types
        if engine_types is not None:
            self.engine_types = engine_types
        if fibre_channel is not None:
            self.fibre_channel = fibre_channel
        if flash_cache is not None:
            self.flash_cache = flash_cache
        if minimum_drives is not None:
            self.minimum_drives = minimum_drives
        if supports_app_engines is not None:
            self.supports_app_engines = supports_app_engines
        if zios is not None:
            self.zios = zios
        if zones is not None:
            self.zones = zones
        if vpsa_zone_group_storage_policy_types is not None:
            self.vpsa_zone_group_storage_policy_types = vpsa_zone_group_storage_policy_types
        if recommended_storage_array_image_id is not None:
            self.recommended_storage_array_image_id = recommended_storage_array_image_id
        if last_synced is not None:
            self.last_synced = last_synced
        if sync_status is not None:
            self.sync_status = sync_status

    @property
    def id(self):
        """Gets the id of this Cloud.  # noqa: E501


        :return: The id of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Cloud.


        :param id: The id of this Cloud.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Cloud.  # noqa: E501


        :return: The name of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Cloud.


        :param name: The name of this Cloud.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uuid(self):
        """Gets the uuid of this Cloud.  # noqa: E501


        :return: The uuid of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Cloud.


        :param uuid: The uuid of this Cloud.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def enabled(self):
        """Gets the enabled of this Cloud.  # noqa: E501


        :return: The enabled of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Cloud.


        :param enabled: The enabled of this Cloud.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def app_engines(self):
        """Gets the app_engines of this Cloud.  # noqa: E501


        :return: The app_engines of this Cloud.  # noqa: E501
        :rtype: list[CloudAppEngines]
        """
        return self._app_engines

    @app_engines.setter
    def app_engines(self, app_engines):
        """Sets the app_engines of this Cloud.


        :param app_engines: The app_engines of this Cloud.  # noqa: E501
        :type: list[CloudAppEngines]
        """

        self._app_engines = app_engines

    @property
    def nova_url(self):
        """Gets the nova_url of this Cloud.  # noqa: E501


        :return: The nova_url of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._nova_url

    @nova_url.setter
    def nova_url(self, nova_url):
        """Sets the nova_url of this Cloud.


        :param nova_url: The nova_url of this Cloud.  # noqa: E501
        :type: str
        """

        self._nova_url = nova_url

    @property
    def auth_url(self):
        """Gets the auth_url of this Cloud.  # noqa: E501


        :return: The auth_url of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """Sets the auth_url of this Cloud.


        :param auth_url: The auth_url of this Cloud.  # noqa: E501
        :type: str
        """

        self._auth_url = auth_url

    @property
    def keystone_url(self):
        """Gets the keystone_url of this Cloud.  # noqa: E501


        :return: The keystone_url of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._keystone_url

    @keystone_url.setter
    def keystone_url(self, keystone_url):
        """Sets the keystone_url of this Cloud.


        :param keystone_url: The keystone_url of this Cloud.  # noqa: E501
        :type: str
        """

        self._keystone_url = keystone_url

    @property
    def glance_url(self):
        """Gets the glance_url of this Cloud.  # noqa: E501


        :return: The glance_url of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._glance_url

    @glance_url.setter
    def glance_url(self, glance_url):
        """Sets the glance_url of this Cloud.


        :param glance_url: The glance_url of this Cloud.  # noqa: E501
        :type: str
        """

        self._glance_url = glance_url

    @property
    def drive_types(self):
        """Gets the drive_types of this Cloud.  # noqa: E501


        :return: The drive_types of this Cloud.  # noqa: E501
        :rtype: list[CloudDriveTypes]
        """
        return self._drive_types

    @drive_types.setter
    def drive_types(self, drive_types):
        """Sets the drive_types of this Cloud.


        :param drive_types: The drive_types of this Cloud.  # noqa: E501
        :type: list[CloudDriveTypes]
        """

        self._drive_types = drive_types

    @property
    def engine_types(self):
        """Gets the engine_types of this Cloud.  # noqa: E501


        :return: The engine_types of this Cloud.  # noqa: E501
        :rtype: list[CloudEngineTypes]
        """
        return self._engine_types

    @engine_types.setter
    def engine_types(self, engine_types):
        """Sets the engine_types of this Cloud.


        :param engine_types: The engine_types of this Cloud.  # noqa: E501
        :type: list[CloudEngineTypes]
        """

        self._engine_types = engine_types

    @property
    def fibre_channel(self):
        """Gets the fibre_channel of this Cloud.  # noqa: E501


        :return: The fibre_channel of this Cloud.  # noqa: E501
        :rtype: CloudFibreChannel
        """
        return self._fibre_channel

    @fibre_channel.setter
    def fibre_channel(self, fibre_channel):
        """Sets the fibre_channel of this Cloud.


        :param fibre_channel: The fibre_channel of this Cloud.  # noqa: E501
        :type: CloudFibreChannel
        """

        self._fibre_channel = fibre_channel

    @property
    def flash_cache(self):
        """Gets the flash_cache of this Cloud.  # noqa: E501


        :return: The flash_cache of this Cloud.  # noqa: E501
        :rtype: CloudFlashCache
        """
        return self._flash_cache

    @flash_cache.setter
    def flash_cache(self, flash_cache):
        """Sets the flash_cache of this Cloud.


        :param flash_cache: The flash_cache of this Cloud.  # noqa: E501
        :type: CloudFlashCache
        """

        self._flash_cache = flash_cache

    @property
    def minimum_drives(self):
        """Gets the minimum_drives of this Cloud.  # noqa: E501


        :return: The minimum_drives of this Cloud.  # noqa: E501
        :rtype: int
        """
        return self._minimum_drives

    @minimum_drives.setter
    def minimum_drives(self, minimum_drives):
        """Sets the minimum_drives of this Cloud.


        :param minimum_drives: The minimum_drives of this Cloud.  # noqa: E501
        :type: int
        """

        self._minimum_drives = minimum_drives

    @property
    def supports_app_engines(self):
        """Gets the supports_app_engines of this Cloud.  # noqa: E501


        :return: The supports_app_engines of this Cloud.  # noqa: E501
        :rtype: bool
        """
        return self._supports_app_engines

    @supports_app_engines.setter
    def supports_app_engines(self, supports_app_engines):
        """Sets the supports_app_engines of this Cloud.


        :param supports_app_engines: The supports_app_engines of this Cloud.  # noqa: E501
        :type: bool
        """

        self._supports_app_engines = supports_app_engines

    @property
    def zios(self):
        """Gets the zios of this Cloud.  # noqa: E501


        :return: The zios of this Cloud.  # noqa: E501
        :rtype: CloudFibreChannel
        """
        return self._zios

    @zios.setter
    def zios(self, zios):
        """Sets the zios of this Cloud.


        :param zios: The zios of this Cloud.  # noqa: E501
        :type: CloudFibreChannel
        """

        self._zios = zios

    @property
    def zones(self):
        """Gets the zones of this Cloud.  # noqa: E501


        :return: The zones of this Cloud.  # noqa: E501
        :rtype: list[CloudZones]
        """
        return self._zones

    @zones.setter
    def zones(self, zones):
        """Sets the zones of this Cloud.


        :param zones: The zones of this Cloud.  # noqa: E501
        :type: list[CloudZones]
        """

        self._zones = zones

    @property
    def vpsa_zone_group_storage_policy_types(self):
        """Gets the vpsa_zone_group_storage_policy_types of this Cloud.  # noqa: E501


        :return: The vpsa_zone_group_storage_policy_types of this Cloud.  # noqa: E501
        :rtype: CloudVpsazoneGroupStoragePolicyTypes
        """
        return self._vpsa_zone_group_storage_policy_types

    @vpsa_zone_group_storage_policy_types.setter
    def vpsa_zone_group_storage_policy_types(self, vpsa_zone_group_storage_policy_types):
        """Sets the vpsa_zone_group_storage_policy_types of this Cloud.


        :param vpsa_zone_group_storage_policy_types: The vpsa_zone_group_storage_policy_types of this Cloud.  # noqa: E501
        :type: CloudVpsazoneGroupStoragePolicyTypes
        """

        self._vpsa_zone_group_storage_policy_types = vpsa_zone_group_storage_policy_types

    @property
    def recommended_storage_array_image_id(self):
        """Gets the recommended_storage_array_image_id of this Cloud.  # noqa: E501


        :return: The recommended_storage_array_image_id of this Cloud.  # noqa: E501
        :rtype: int
        """
        return self._recommended_storage_array_image_id

    @recommended_storage_array_image_id.setter
    def recommended_storage_array_image_id(self, recommended_storage_array_image_id):
        """Sets the recommended_storage_array_image_id of this Cloud.


        :param recommended_storage_array_image_id: The recommended_storage_array_image_id of this Cloud.  # noqa: E501
        :type: int
        """

        self._recommended_storage_array_image_id = recommended_storage_array_image_id

    @property
    def last_synced(self):
        """Gets the last_synced of this Cloud.  # noqa: E501


        :return: The last_synced of this Cloud.  # noqa: E501
        :rtype: str
        """
        return self._last_synced

    @last_synced.setter
    def last_synced(self, last_synced):
        """Sets the last_synced of this Cloud.


        :param last_synced: The last_synced of this Cloud.  # noqa: E501
        :type: str
        """

        self._last_synced = last_synced

    @property
    def sync_status(self):
        """Gets the sync_status of this Cloud.  # noqa: E501


        :return: The sync_status of this Cloud.  # noqa: E501
        :rtype: CloudSyncStatus
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """Sets the sync_status of this Cloud.


        :param sync_status: The sync_status of this Cloud.  # noqa: E501
        :type: CloudSyncStatus
        """

        self._sync_status = sync_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Cloud, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cloud):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Cloud):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class SetEncriptionPassOrUseAwsKmsStore(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'region': 'str',
        'kmskeyid': 'str',
        'access_id': 'str',
        'secret': 'str',
        'encryption_pwd': 'str',
        'old_encryption_pwd': 'str',
        'password': 'str'
    }

    attribute_map = {
        'region': 'region',
        'kmskeyid': 'kmskeyid',
        'access_id': 'access_id',
        'secret': 'secret',
        'encryption_pwd': 'encryption_pwd',
        'old_encryption_pwd': 'old_encryption_pwd',
        'password': 'password'
    }

    def __init__(self, region=None, kmskeyid=None, access_id=None, secret=None, encryption_pwd=None, old_encryption_pwd=None, password=None, _configuration=None):  # noqa: E501
        """SetEncriptionPassOrUseAwsKmsStore - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._region = None
        self._kmskeyid = None
        self._access_id = None
        self._secret = None
        self._encryption_pwd = None
        self._old_encryption_pwd = None
        self._password = None
        self.discriminator = None

        if region is not None:
            self.region = region
        if kmskeyid is not None:
            self.kmskeyid = kmskeyid
        if access_id is not None:
            self.access_id = access_id
        if secret is not None:
            self.secret = secret
        if encryption_pwd is not None:
            self.encryption_pwd = encryption_pwd
        if old_encryption_pwd is not None:
            self.old_encryption_pwd = old_encryption_pwd
        if password is not None:
            self.password = password

    @property
    def region(self):
        """Gets the region of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The region of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this SetEncriptionPassOrUseAwsKmsStore.


        :param region: The region of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def kmskeyid(self):
        """Gets the kmskeyid of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The kmskeyid of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._kmskeyid

    @kmskeyid.setter
    def kmskeyid(self, kmskeyid):
        """Sets the kmskeyid of this SetEncriptionPassOrUseAwsKmsStore.


        :param kmskeyid: The kmskeyid of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._kmskeyid = kmskeyid

    @property
    def access_id(self):
        """Gets the access_id of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The access_id of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._access_id

    @access_id.setter
    def access_id(self, access_id):
        """Sets the access_id of this SetEncriptionPassOrUseAwsKmsStore.


        :param access_id: The access_id of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._access_id = access_id

    @property
    def secret(self):
        """Gets the secret of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The secret of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this SetEncriptionPassOrUseAwsKmsStore.


        :param secret: The secret of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def encryption_pwd(self):
        """Gets the encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._encryption_pwd

    @encryption_pwd.setter
    def encryption_pwd(self, encryption_pwd):
        """Sets the encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.


        :param encryption_pwd: The encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._encryption_pwd = encryption_pwd

    @property
    def old_encryption_pwd(self):
        """Gets the old_encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The old_encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._old_encryption_pwd

    @old_encryption_pwd.setter
    def old_encryption_pwd(self, old_encryption_pwd):
        """Sets the old_encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.


        :param old_encryption_pwd: The old_encryption_pwd of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._old_encryption_pwd = old_encryption_pwd

    @property
    def password(self):
        """Gets the password of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501


        :return: The password of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this SetEncriptionPassOrUseAwsKmsStore.


        :param password: The password of this SetEncriptionPassOrUseAwsKmsStore.  # noqa: E501
        :type: str
        """

        self._password = password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetEncriptionPassOrUseAwsKmsStore, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetEncriptionPassOrUseAwsKmsStore):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SetEncriptionPassOrUseAwsKmsStore):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class EngineTypesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_app_engine(self, cloud_name, name, **kwargs):  # noqa: E501
        """get_app_engine  # noqa: E501

        Returns a single APP engine type details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_app_engine(cloud_name, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20032
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_app_engine_with_http_info(cloud_name, name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_app_engine_with_http_info(cloud_name, name, **kwargs)  # noqa: E501
            return data

    def get_app_engine_with_http_info(self, cloud_name, name, **kwargs):  # noqa: E501
        """get_app_engine  # noqa: E501

        Returns a single APP engine type details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_app_engine_with_http_info(cloud_name, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20032
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_app_engine" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_app_engine`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in params or
                                                       params['name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `get_app_engine`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/app_engine_types/{name}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20032',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_io_engine(self, cloud_name, internal_id, **kwargs):  # noqa: E501
        """get_io_engine  # noqa: E501

        Returns a single IO engine type details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_io_engine(cloud_name, internal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str internal_id: (required)
        :return: InlineResponse20030
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_io_engine_with_http_info(cloud_name, internal_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_io_engine_with_http_info(cloud_name, internal_id, **kwargs)  # noqa: E501
            return data

    def get_io_engine_with_http_info(self, cloud_name, internal_id, **kwargs):  # noqa: E501
        """get_io_engine  # noqa: E501

        Returns a single IO engine type details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_io_engine_with_http_info(cloud_name, internal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str internal_id: (required)
        :return: InlineResponse20030
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'internal_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_io_engine" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_io_engine`")  # noqa: E501
        # verify the required parameter 'internal_id' is set
        if self.api_client.client_side_validation and ('internal_id' not in params or
                                                       params['internal_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `internal_id` when calling `get_io_engine`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'internal_id' in params:
            path_params['internal_id'] = params['internal_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/engine_types/{internal_id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20030',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_cloud_io_engine_types(self, cloud_name, **kwargs):  # noqa: E501
        """list_cloud_io_engine_types  # noqa: E501

        Returns a list of Cloud's IO engine types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_io_engine_types(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_cloud_io_engine_types_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_cloud_io_engine_types_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_cloud_io_engine_types_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_cloud_io_engine_types  # noqa: E501

        Returns a list of Cloud's IO engine types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_cloud_io_engine_types_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cloud_io_engine_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_cloud_io_engine_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/engine_types.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_clouds_app_engine_types(self, cloud_name, **kwargs):  # noqa: E501
        """list_clouds_app_engine_types  # noqa: E501

        Returns a list of Cloud's APP engine types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clouds_app_engine_types(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20031
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_clouds_app_engine_types_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_clouds_app_engine_types_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_clouds_app_engine_types_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_clouds_app_engine_types  # noqa: E501

        Returns a list of Cloud's APP engine types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clouds_app_engine_types_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20031
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_clouds_app_engine_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_clouds_app_engine_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/app_engine_types.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20031',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ProvisioningPortal.api_client import ApiClient


class ProvidersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_provider(self, create_provider, **kwargs):  # noqa: E501
        """create_provider  # noqa: E501

        Create a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_provider(create_provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProvider create_provider: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_provider_with_http_info(create_provider, **kwargs)  # noqa: E501
        else:
            (data) = self.create_provider_with_http_info(create_provider, **kwargs)  # noqa: E501
            return data

    def create_provider_with_http_info(self, create_provider, **kwargs):  # noqa: E501
        """create_provider  # noqa: E501

        Create a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_provider_with_http_info(create_provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProvider create_provider: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_provider']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_provider" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_provider' is set
        if self.api_client.client_side_validation and ('create_provider' not in params or
                                                       params['create_provider'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_provider` when calling `create_provider`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_provider' in params:
            body_params = params['create_provider']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20010',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_provider_group(self, create_provider_group, **kwargs):  # noqa: E501
        """create_provider_group  # noqa: E501

        Create a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_provider_group(create_provider_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProviderGroup create_provider_group: (required)
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_provider_group_with_http_info(create_provider_group, **kwargs)  # noqa: E501
        else:
            (data) = self.create_provider_group_with_http_info(create_provider_group, **kwargs)  # noqa: E501
            return data

    def create_provider_group_with_http_info(self, create_provider_group, **kwargs):  # noqa: E501
        """create_provider_group  # noqa: E501

        Create a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_provider_group_with_http_info(create_provider_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateProviderGroup create_provider_group: (required)
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_provider_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_provider_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_provider_group' is set
        if self.api_client.client_side_validation and ('create_provider_group' not in params or
                                                       params['create_provider_group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_provider_group` when calling `create_provider_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_provider_group' in params:
            body_params = params['create_provider_group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/provider_groups.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20013',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_provider(self, id, **kwargs):  # noqa: E501
        """delete_provider  # noqa: E501

        Delete a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_provider(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_provider_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_provider_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_provider_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_provider  # noqa: E501

        Delete a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_provider_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_provider" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_provider`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_provider_group(self, id, **kwargs):  # noqa: E501
        """delete_provider_group  # noqa: E501

        Delete a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_provider_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_provider_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_provider_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_provider_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_provider_group  # noqa: E501

        Delete a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_provider_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_provider_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_provider_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/provider_groups/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_providers(self, **kwargs):  # noqa: E501
        """get_available_providers  # noqa: E501

        Get the list of available Providers and their configuration options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_providers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse2009
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_providers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_providers_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_providers_with_http_info(self, **kwargs):  # noqa: E501
        """get_available_providers  # noqa: E501

        Get the list of available Providers and their configuration options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_providers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse2009
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_providers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2009',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provider(self, id, **kwargs):  # noqa: E501
        """get_provider  # noqa: E501

        Get the configuration information for a single provider.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_provider_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_provider_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_provider_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_provider  # noqa: E501

        Get the configuration information for a single provider.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20011
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provider" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_provider`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20011',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provider_group(self, id, **kwargs):  # noqa: E501
        """get_provider_group  # noqa: E501

        Get the configuration information for a single Provider Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider_group(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_provider_group_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_provider_group_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_provider_group_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_provider_group  # noqa: E501

        Get the configuration information for a single Provider Group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider_group_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20014
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provider_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_provider_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/provider_groups/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20014',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provider_groups(self, **kwargs):  # noqa: E501
        """get_provider_groups  # noqa: E501

        Get the list of provider groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_provider_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_provider_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_provider_groups_with_http_info(self, **kwargs):  # noqa: E501
        """get_provider_groups  # noqa: E501

        Get the list of provider groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_provider_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20012
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provider_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/provider_groups.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20012',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_flavor_price(self, provider_id, flavor_key, set_flavor_price, **kwargs):  # noqa: E501
        """set_flavor_price  # noqa: E501

        Set the flavor price. flavor_key can be id / nova_id_{nova_id} / nova_type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_flavor_price(provider_id, flavor_key, set_flavor_price, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str provider_id: (required)
        :param str flavor_key: (required)
        :param SetFlavorPrice set_flavor_price: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_flavor_price_with_http_info(provider_id, flavor_key, set_flavor_price, **kwargs)  # noqa: E501
        else:
            (data) = self.set_flavor_price_with_http_info(provider_id, flavor_key, set_flavor_price, **kwargs)  # noqa: E501
            return data

    def set_flavor_price_with_http_info(self, provider_id, flavor_key, set_flavor_price, **kwargs):  # noqa: E501
        """set_flavor_price  # noqa: E501

        Set the flavor price. flavor_key can be id / nova_id_{nova_id} / nova_type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_flavor_price_with_http_info(provider_id, flavor_key, set_flavor_price, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str provider_id: (required)
        :param str flavor_key: (required)
        :param SetFlavorPrice set_flavor_price: (required)
        :return: InlineResponse2006
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['provider_id', 'flavor_key', 'set_flavor_price']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_flavor_price" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'provider_id' is set
        if self.api_client.client_side_validation and ('provider_id' not in params or
                                                       params['provider_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `provider_id` when calling `set_flavor_price`")  # noqa: E501
        # verify the required parameter 'flavor_key' is set
        if self.api_client.client_side_validation and ('flavor_key' not in params or
                                                       params['flavor_key'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `flavor_key` when calling `set_flavor_price`")  # noqa: E501
        # verify the required parameter 'set_flavor_price' is set
        if self.api_client.client_side_validation and ('set_flavor_price' not in params or
                                                       params['set_flavor_price'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `set_flavor_price` when calling `set_flavor_price`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'provider_id' in params:
            path_params['provider_id'] = params['provider_id']  # noqa: E501
        if 'flavor_key' in params:
            path_params['flavor_key'] = params['flavor_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_flavor_price' in params:
            body_params = params['set_flavor_price']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers/{provider_id}/flavors/{flavor_key}/price.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_provider(self, id, update_provider, **kwargs):  # noqa: E501
        """update_provider  # noqa: E501

        Update a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_provider(id, update_provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateProvider update_provider: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_provider_with_http_info(id, update_provider, **kwargs)  # noqa: E501
        else:
            (data) = self.update_provider_with_http_info(id, update_provider, **kwargs)  # noqa: E501
            return data

    def update_provider_with_http_info(self, id, update_provider, **kwargs):  # noqa: E501
        """update_provider  # noqa: E501

        Update a provider  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_provider_with_http_info(id, update_provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateProvider update_provider: (required)
        :return: InlineResponse20010
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_provider']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_provider" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_provider`")  # noqa: E501
        # verify the required parameter 'update_provider' is set
        if self.api_client.client_side_validation and ('update_provider' not in params or
                                                       params['update_provider'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_provider` when calling `update_provider`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_provider' in params:
            body_params = params['update_provider']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/providers/{id}.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20010',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_provider_group(self, id, update_provider_group, **kwargs):  # noqa: E501
        """update_provider_group  # noqa: E501

        Update a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_provider_group(id, update_provider_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateProviderGroup update_provider_group: (required)
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_provider_group_with_http_info(id, update_provider_group, **kwargs)  # noqa: E501
        else:
            (data) = self.update_provider_group_with_http_info(id, update_provider_group, **kwargs)  # noqa: E501
            return data

    def update_provider_group_with_http_info(self, id, update_provider_group, **kwargs):  # noqa: E501
        """update_provider_group  # noqa: E501

        Update a provider group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_provider_group_with_http_info(id, update_provider_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateProviderGroup update_provider_group: (required)
        :return: InlineResponse20013
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_provider_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_provider_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_provider_group`")  # noqa: E501
        # verify the required parameter 'update_provider_group' is set
        if self.api_client.client_side_validation and ('update_provider_group' not in params or
                                                       params['update_provider_group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_provider_group` when calling `update_provider_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_provider_group' in params:
            body_params = params['update_provider_group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/provider_groups/{id}.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20013',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20023ResponseVcontrollers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'index': 'int',
        'name': 'str',
        'state': 'str',
        'encryption_password_set': 'str',
        'is_encryption_active': 'str',
        'mgmt_ip': 'str',
        'mgmt_ipv6': 'str',
        'software_version': 'str',
        'recycle_bin': 'str',
        'recycle_bin_grace_period': 'int',
        'target': 'str',
        'iscsi_ip': 'str',
        'iscsi_ipv6': 'str',
        'vpsa_chap_user': 'str',
        'vpsa_chap_secret': 'str',
        'host_chap_user': 'str',
        'host_chap_secret': 'str'
    }

    attribute_map = {
        'index': 'index',
        'name': 'name',
        'state': 'state',
        'encryption_password_set': 'encryption_password_set',
        'is_encryption_active': 'is_encryption_active',
        'mgmt_ip': 'mgmt_ip',
        'mgmt_ipv6': 'mgmt-ipv6',
        'software_version': 'software_version',
        'recycle_bin': 'recycle_bin',
        'recycle_bin_grace_period': 'recycle_bin_grace_period',
        'target': 'target',
        'iscsi_ip': 'iscsi_ip',
        'iscsi_ipv6': 'iscsi_ipv6',
        'vpsa_chap_user': 'vpsa_chap_user',
        'vpsa_chap_secret': 'vpsa_chap_secret',
        'host_chap_user': 'host_chap_user',
        'host_chap_secret': 'host_chap_secret'
    }

    def __init__(self, index=None, name=None, state=None, encryption_password_set=None, is_encryption_active=None, mgmt_ip=None, mgmt_ipv6=None, software_version=None, recycle_bin=None, recycle_bin_grace_period=None, target=None, iscsi_ip=None, iscsi_ipv6=None, vpsa_chap_user=None, vpsa_chap_secret=None, host_chap_user=None, host_chap_secret=None, _configuration=None):  # noqa: E501
        """InlineResponse20023ResponseVcontrollers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._index = None
        self._name = None
        self._state = None
        self._encryption_password_set = None
        self._is_encryption_active = None
        self._mgmt_ip = None
        self._mgmt_ipv6 = None
        self._software_version = None
        self._recycle_bin = None
        self._recycle_bin_grace_period = None
        self._target = None
        self._iscsi_ip = None
        self._iscsi_ipv6 = None
        self._vpsa_chap_user = None
        self._vpsa_chap_secret = None
        self._host_chap_user = None
        self._host_chap_secret = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if name is not None:
            self.name = name
        if state is not None:
            self.state = state
        if encryption_password_set is not None:
            self.encryption_password_set = encryption_password_set
        if is_encryption_active is not None:
            self.is_encryption_active = is_encryption_active
        if mgmt_ip is not None:
            self.mgmt_ip = mgmt_ip
        if mgmt_ipv6 is not None:
            self.mgmt_ipv6 = mgmt_ipv6
        if software_version is not None:
            self.software_version = software_version
        if recycle_bin is not None:
            self.recycle_bin = recycle_bin
        if recycle_bin_grace_period is not None:
            self.recycle_bin_grace_period = recycle_bin_grace_period
        if target is not None:
            self.target = target
        if iscsi_ip is not None:
            self.iscsi_ip = iscsi_ip
        if iscsi_ipv6 is not None:
            self.iscsi_ipv6 = iscsi_ipv6
        if vpsa_chap_user is not None:
            self.vpsa_chap_user = vpsa_chap_user
        if vpsa_chap_secret is not None:
            self.vpsa_chap_secret = vpsa_chap_secret
        if host_chap_user is not None:
            self.host_chap_user = host_chap_user
        if host_chap_secret is not None:
            self.host_chap_secret = host_chap_secret

    @property
    def index(self):
        """Gets the index of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The index of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this InlineResponse20023ResponseVcontrollers.


        :param index: The index of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def name(self):
        """Gets the name of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The name of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20023ResponseVcontrollers.


        :param name: The name of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """Gets the state of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The state of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20023ResponseVcontrollers.


        :param state: The state of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def encryption_password_set(self):
        """Gets the encryption_password_set of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The encryption_password_set of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._encryption_password_set

    @encryption_password_set.setter
    def encryption_password_set(self, encryption_password_set):
        """Sets the encryption_password_set of this InlineResponse20023ResponseVcontrollers.


        :param encryption_password_set: The encryption_password_set of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._encryption_password_set = encryption_password_set

    @property
    def is_encryption_active(self):
        """Gets the is_encryption_active of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The is_encryption_active of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._is_encryption_active

    @is_encryption_active.setter
    def is_encryption_active(self, is_encryption_active):
        """Sets the is_encryption_active of this InlineResponse20023ResponseVcontrollers.


        :param is_encryption_active: The is_encryption_active of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._is_encryption_active = is_encryption_active

    @property
    def mgmt_ip(self):
        """Gets the mgmt_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The mgmt_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._mgmt_ip

    @mgmt_ip.setter
    def mgmt_ip(self, mgmt_ip):
        """Sets the mgmt_ip of this InlineResponse20023ResponseVcontrollers.


        :param mgmt_ip: The mgmt_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._mgmt_ip = mgmt_ip

    @property
    def mgmt_ipv6(self):
        """Gets the mgmt_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The mgmt_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._mgmt_ipv6

    @mgmt_ipv6.setter
    def mgmt_ipv6(self, mgmt_ipv6):
        """Sets the mgmt_ipv6 of this InlineResponse20023ResponseVcontrollers.


        :param mgmt_ipv6: The mgmt_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._mgmt_ipv6 = mgmt_ipv6

    @property
    def software_version(self):
        """Gets the software_version of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The software_version of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this InlineResponse20023ResponseVcontrollers.


        :param software_version: The software_version of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._software_version = software_version

    @property
    def recycle_bin(self):
        """Gets the recycle_bin of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The recycle_bin of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._recycle_bin

    @recycle_bin.setter
    def recycle_bin(self, recycle_bin):
        """Sets the recycle_bin of this InlineResponse20023ResponseVcontrollers.


        :param recycle_bin: The recycle_bin of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._recycle_bin = recycle_bin

    @property
    def recycle_bin_grace_period(self):
        """Gets the recycle_bin_grace_period of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The recycle_bin_grace_period of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._recycle_bin_grace_period

    @recycle_bin_grace_period.setter
    def recycle_bin_grace_period(self, recycle_bin_grace_period):
        """Sets the recycle_bin_grace_period of this InlineResponse20023ResponseVcontrollers.


        :param recycle_bin_grace_period: The recycle_bin_grace_period of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._recycle_bin_grace_period = recycle_bin_grace_period

    @property
    def target(self):
        """Gets the target of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The target of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse20023ResponseVcontrollers.


        :param target: The target of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def iscsi_ip(self):
        """Gets the iscsi_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The iscsi_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ip

    @iscsi_ip.setter
    def iscsi_ip(self, iscsi_ip):
        """Sets the iscsi_ip of this InlineResponse20023ResponseVcontrollers.


        :param iscsi_ip: The iscsi_ip of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._iscsi_ip = iscsi_ip

    @property
    def iscsi_ipv6(self):
        """Gets the iscsi_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The iscsi_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ipv6

    @iscsi_ipv6.setter
    def iscsi_ipv6(self, iscsi_ipv6):
        """Sets the iscsi_ipv6 of this InlineResponse20023ResponseVcontrollers.


        :param iscsi_ipv6: The iscsi_ipv6 of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._iscsi_ipv6 = iscsi_ipv6

    @property
    def vpsa_chap_user(self):
        """Gets the vpsa_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The vpsa_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_user

    @vpsa_chap_user.setter
    def vpsa_chap_user(self, vpsa_chap_user):
        """Sets the vpsa_chap_user of this InlineResponse20023ResponseVcontrollers.


        :param vpsa_chap_user: The vpsa_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_user = vpsa_chap_user

    @property
    def vpsa_chap_secret(self):
        """Gets the vpsa_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The vpsa_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_secret

    @vpsa_chap_secret.setter
    def vpsa_chap_secret(self, vpsa_chap_secret):
        """Sets the vpsa_chap_secret of this InlineResponse20023ResponseVcontrollers.


        :param vpsa_chap_secret: The vpsa_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_secret = vpsa_chap_secret

    @property
    def host_chap_user(self):
        """Gets the host_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The host_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._host_chap_user

    @host_chap_user.setter
    def host_chap_user(self, host_chap_user):
        """Sets the host_chap_user of this InlineResponse20023ResponseVcontrollers.


        :param host_chap_user: The host_chap_user of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._host_chap_user = host_chap_user

    @property
    def host_chap_secret(self):
        """Gets the host_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501


        :return: The host_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._host_chap_secret

    @host_chap_secret.setter
    def host_chap_secret(self, host_chap_secret):
        """Sets the host_chap_secret of this InlineResponse20023ResponseVcontrollers.


        :param host_chap_secret: The host_chap_secret of this InlineResponse20023ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._host_chap_secret = host_chap_secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20023ResponseVcontrollers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20023ResponseVcontrollers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20023ResponseVcontrollers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Zios.api_client import ApiClient


class UsageReportsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def generate_usage_reports(self, **kwargs):  # noqa: E501
        """generate_usage_reports  # noqa: E501

        Generate a usage report. Each account lists the following for each policy: capacity, number of objects, number of containers, data transfer in, data transfer out  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_usage_reports(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_time: Type of time frame for report
        :param str report_type: Type of time frame for report
        :param str fromdate: Start time (YYYY-MM-DD). Required for custom report.
        :param str todate: End time (YYYY-MM-DD). Required for custom report.
        :param str month: Month of the year, (e.g. 4). Required for monthly report.
        :param str account_id: Account id. Default is user's account.
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_usage_reports_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.generate_usage_reports_with_http_info(**kwargs)  # noqa: E501
            return data

    def generate_usage_reports_with_http_info(self, **kwargs):  # noqa: E501
        """generate_usage_reports  # noqa: E501

        Generate a usage report. Each account lists the following for each policy: capacity, number of objects, number of containers, data transfer in, data transfer out  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_usage_reports_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_time: Type of time frame for report
        :param str report_type: Type of time frame for report
        :param str fromdate: Start time (YYYY-MM-DD). Required for custom report.
        :param str todate: End time (YYYY-MM-DD). Required for custom report.
        :param str month: Month of the year, (e.g. 4). Required for monthly report.
        :param str account_id: Account id. Default is user's account.
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_time', 'report_type', 'fromdate', 'todate', 'month', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_usage_reports" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'report_time' in params:
            query_params.append(('report_time', params['report_time']))  # noqa: E501
        if 'report_type' in params:
            query_params.append(('report_type', params['report_type']))  # noqa: E501
        if 'fromdate' in params:
            query_params.append(('fromdate', params['fromdate']))  # noqa: E501
        if 'todate' in params:
            query_params.append(('todate', params['todate']))  # noqa: E501
        if 'month' in params:
            query_params.append(('month', params['month']))  # noqa: E501
        if 'account_id' in params:
            query_params.append(('account_id', params['account_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/zios/usage_reports/generate.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20048',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
